@@ -22,8 +22,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
-
 #include "configdialog.h"
 #include "field.h"
 #include "collection.h"
@@ -37,6 +35,7 @@
 #include "utils/tellico_utils.h"
 #include "utils/string_utils.h"
 #include "config/tellico_config.h"
+#include "core/tellico_strings.h"
 #include "images/imagefactory.h"
 #include "gui/combobox.h"
 #include "gui/collectiontypecombo.h"
@@ -53,7 +52,11 @@
 #include <KRecentDirs>
 
 #ifdef ENABLE_KNEWSTUFF3
-#include <KNS3/DownloadDialog>
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
+#include <KNS3/Button>
+#else
+#include <KNSWidgets/Button>
+#endif
 #endif
 
 #include <QSpinBox>
@@ -563,10 +566,20 @@ void ConfigDialog::initTemplatePage(QFrame* frame) {
   whats = i18n("Click to install a new template directly.");
   b1->setWhatsThis(whats);
 
+#ifdef ENABLE_KNEWSTUFF3
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
+  auto b2 = new KNS3::Button(i18n("Download..."), QStringLiteral("tellico-template.knsrc"), box1);
+  connect(b2, &KNS3::Button::dialogFinished, this, &ConfigDialog::slotUpdateTemplates);
+#else
+  auto b2 = new KNSWidgets::Button(i18n("Download..."), QStringLiteral("tellico-template.knsrc"), box1);
+  connect(b2, &KNSWidgets::Button::dialogFinished, this, &ConfigDialog::slotUpdateTemplates);
+#endif
+#else
   QPushButton* b2 = new QPushButton(i18n("Download..."), box1);
-  box1HBoxLayout->addWidget(b2);
   b2->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-  connect(b2, &QAbstractButton::clicked, this, &ConfigDialog::slotDownloadTemplate);
+  b2->setEnabled(false);
+#endif
+  box1HBoxLayout->addWidget(b2);
   whats = i18n("Click to download additional templates.");
   b2->setWhatsThis(whats);
 
@@ -630,13 +643,13 @@ void ConfigDialog::initFetchPage(QFrame* frame) {
   m_moveUpSourceBtn = new QPushButton(i18n("Move &Up"), hb);
   hbHBoxLayout->addWidget(m_moveUpSourceBtn);
   m_moveUpSourceBtn->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-  m_moveUpSourceBtn->setWhatsThis(i18n("The order of the data sources sets the order "
-                                       "that Tellico uses when entries are automatically updated."));
+  const QString moveTip(i18n("The order of the data sources sets the order "
+                             "that Tellico uses when entries are automatically updated."));
+  m_moveUpSourceBtn->setWhatsThis(moveTip);
   m_moveDownSourceBtn = new QPushButton(i18n("Move &Down"), hb);
   hbHBoxLayout->addWidget(m_moveDownSourceBtn);
   m_moveDownSourceBtn->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-  m_moveDownSourceBtn->setWhatsThis(i18n("The order of the data sources sets the order "
-                                         "that Tellico uses when entries are automatically updated."));
+  m_moveDownSourceBtn->setWhatsThis(moveTip);
 
   QWidget* hb2 = new QWidget(frame);
   QHBoxLayout* hb2HBoxLayout = new QHBoxLayout(hb2);
@@ -669,18 +682,10 @@ void ConfigDialog::initFetchPage(QFrame* frame) {
   m_removeSourceBtn = new QPushButton(i18n("&Delete"), frame);
   m_removeSourceBtn->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
   m_removeSourceBtn->setWhatsThis(i18n("Click to delete the selected data source."));
-  m_newStuffBtn = new QPushButton(i18n("Download..."), frame);
-  m_newStuffBtn->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-  m_newStuffBtn->setWhatsThis(i18n("Click to download additional data sources."));
-  // TODO: disable button for now since checksum and signature checking are no longer possible with khotnewstuff
-  m_newStuffBtn->setEnabled(false);
 
   vlay->addWidget(newSourceBtn);
   vlay->addWidget(m_modifySourceBtn);
   vlay->addWidget(m_removeSourceBtn);
-  // separate newstuff button from the rest
-  vlay->addSpacing(16);
-  vlay->addWidget(m_newStuffBtn);
   vlay->addStretch(1);
 
   connect(newSourceBtn, &QAbstractButton::clicked, this, &ConfigDialog::slotNewSourceClicked);
@@ -688,7 +693,6 @@ void ConfigDialog::initFetchPage(QFrame* frame) {
   connect(m_moveUpSourceBtn, &QAbstractButton::clicked, this, &ConfigDialog::slotMoveUpSourceClicked);
   connect(m_moveDownSourceBtn, &QAbstractButton::clicked, this, &ConfigDialog::slotMoveDownSourceClicked);
   connect(m_removeSourceBtn, &QAbstractButton::clicked, this, &ConfigDialog::slotRemoveSourceClicked);
-  connect(m_newStuffBtn, &QAbstractButton::clicked, this, &ConfigDialog::slotNewStuffClicked);
 
   KAcceleratorManager::manage(frame);
   m_initializedPages |= Fetch;
@@ -835,7 +839,17 @@ void ConfigDialog::savePrintingConfig() {
 
 void ConfigDialog::saveTemplateConfig() {
   const int collType = Kernel::self()->collectionType();
-  Config::setTemplateName(collType, m_templateCombo->currentData().toString());
+  if(collType == Data::Collection::Base &&
+     Kernel::self()->URL().fileName() != i18n(Tellico::untitledFilename)) {
+    // use a nested config group for template specific to custom collections
+    // using the filename alone as a keyEvents
+    const QString configGroup = QStringLiteral("Options - %1").arg(CollectionFactory::typeName(collType));
+    KConfigGroup group(KSharedConfig::openConfig(), configGroup);
+    KConfigGroup subGroup(&group, Kernel::self()->URL().fileName());
+    subGroup.writeEntry(QStringLiteral("Template Name"), m_templateCombo->currentData().toString());
+  } else {
+    Config::setTemplateName(collType, m_templateCombo->currentData().toString());
+  }
   QFont font(m_fontCombo->currentFont().family(), m_fontSizeInput->value());
   Config::setTemplateFont(collType, font);
   Config::setTemplateBaseColor(collType, m_baseColorCombo->color());
@@ -947,21 +961,23 @@ void ConfigDialog::slotNewSourceClicked() {
 
 void ConfigDialog::slotModifySourceClicked() {
   FetcherInfoListItem* item = static_cast<FetcherInfoListItem*>(m_sourceListWidget->currentItem());
-  if(!item || !item->fetcher()) {
+  if(!item) {
     return;
   }
 
   Fetch::ConfigWidget* cw = nullptr;
   if(m_configWidgets.contains(item)) {
     cw = m_configWidgets[item];
-  } else {
+  } else if(item->fetcher()) {
     // grab the config widget, taking ownership
     cw = item->fetcher()->configWidget(this);
-    if(cw) { // might return 0 when no widget available for fetcher type
+    if(cw) { // might return null when no widget available for fetcher type
       m_configWidgets.insert(item, cw);
       // there's weird layout bug if it's not hidden
       cw->hide();
     }
+  } else {
+    myDebug() << "no config item fetcher!";
   }
   if(!cw) {
     // no config widget for this one
@@ -1041,19 +1057,6 @@ void ConfigDialog::slotSelectedSourceChanged(QListWidgetItem* item_) {
   m_moveDownSourceBtn->setEnabled(row < m_sourceListWidget->count()-1);
 }
 
-void ConfigDialog::slotNewStuffClicked() {
-#ifdef ENABLE_KNEWSTUFF3
-  KNS3::DownloadDialog dialog(QStringLiteral("tellico-script.knsrc"), this);
-  dialog.exec();
-
-  KNS3::Entry::List entries = dialog.installedEntries();
-  if(!entries.isEmpty()) {
-    Fetch::Manager::self()->loadFetchers();
-    readFetchConfig();
-  }
-#endif
-}
-
 Tellico::FetcherInfoListItem* ConfigDialog::findItem(const QString& path_) const {
   if(path_.isEmpty()) {
     myDebug() << "empty path";
@@ -1168,17 +1171,17 @@ void ConfigDialog::slotInstallTemplate() {
   }
 }
 
-void ConfigDialog::slotDownloadTemplate() {
 #ifdef ENABLE_KNEWSTUFF3
-  KNS3::DownloadDialog dialog(QStringLiteral("tellico-template.knsrc"), this);
-  dialog.exec();
-
-  KNS3::Entry::List entries = dialog.installedEntries();
-  if(!entries.isEmpty()) {
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 91, 0)
+void ConfigDialog::slotUpdateTemplates(const QList<KNS3::Entry>& list_) {
+#else
+void ConfigDialog::slotUpdateTemplates(const QList<KNSCore::Entry>& list_) {
+#endif
+  if(!list_.isEmpty()) {
     loadTemplateList();
   }
-#endif
 }
+#endif
 
 void ConfigDialog::slotDeleteTemplate() {
   bool ok;
