@@ -135,7 +135,7 @@ void DiscogsFetcher::continueSearch() {
       break;
 
     default:
-      myWarning() << "key not recognized:" << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
