@@ -98,7 +98,7 @@ QUrl GiantBombFetcher::searchUrl() {
       break;
 
     default:
-      myWarning() << "key not recognized: " << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       return QUrl();
   }
   u.setQuery(q);
