@@ -119,7 +119,7 @@ void IGDBFetcher::continueSearch() {
       break;
 
     default:
-      myWarning() << "key not recognized:" << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
