@@ -161,7 +161,7 @@ void ISBNdbFetcher::doSearch(const QString& term_) {
       break;
 
     default:
-      myWarning() << "key not recognized: " << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
