@@ -120,9 +120,6 @@ void TheMovieDBFetcher::saveConfigHook(KConfigGroup& config_) {
 }
 
 void TheMovieDBFetcher::search() {
-  if(m_imageBase.isEmpty() || m_serverConfigDate.daysTo(QDate::currentDate()) > 7) {
-    readConfiguration();
-  }
   continueSearch();
 }
 
@@ -159,7 +156,7 @@ void TheMovieDBFetcher::continueSearch() {
       break;
 
     default:
-      myWarning() << "key not recognized:" << request().key();
+      myWarning() << source() << "- key not recognized:" << request().key();
       stop();
       return;
   }
@@ -192,6 +189,10 @@ Tellico::Data::EntryPtr TheMovieDBFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
+  if(m_imageBase.isEmpty() || m_serverConfigDate.daysTo(QDate::currentDate()) > 7) {
+    readConfiguration();
+  }
+
   QString id = entry->field(QStringLiteral("tmdb-id"));
   if(!id.isEmpty()) {
     const QString mediaType = entry->field(QStringLiteral("tmdb-type"));
