@@ -32,9 +32,11 @@
 
 #include <QDateTime>
 
+using namespace Tellico;
+
 Tellico::FieldComparison* Tellico::FieldComparison::create(Data::FieldPtr field_) {
   if(!field_) {
-    myWarning() << "No field for creating a field comparison";
+//    myWarning() << "No field for creating a field comparison";
     return nullptr;
   }
   if(field_->type() == Data::Field::Image) {
